unit RAPI;

interface

Uses Windows, ActiveX;

type
  {types for compatibility with windows.h}
  LONG=longint;

const
  RAPI_DLL='rapi.dll';
  E_SUCCESS=$00000000;
  E_FAIL=$80004005;

type
  PLONG = ^LONG;

//
// The Windows CE WIN32_FIND_DATA structure differs from the
// Windows WIN32_FIND_DATA stucture so we copy the Windows CE
// definition to here so that both sides match.
//
  CE_FIND_DATA = packed record
    dwFileAttributes: DWORD;
    ftCreationTime: TFILETIME;
    ftLastAccessTime: TFILETIME;
    ftLastWriteTime: TFILETIME;
    nFileSizeHigh: DWORD;
    nFileSizeLow: DWORD;
    dwOID: DWORD;
    cFileName: array [0..MAX_PATH-1] of WCHAR;
  end;

  LPCE_FIND_DATA = ^CE_FIND_DATA;

const
     FAF_ATTRIBUTES=$01;
     FAF_CREATION_TIME=$02;
     FAF_LASTACCESS_TIME=$04;
     FAF_LASTWRITE_TIME=$08;
     FAF_SIZE_HIGH=$10;
     FAF_SIZE_LOW=$20;
     FAF_OID=$40;
     FAF_NAME=$80;
     FAF_FLAG_COUNT=8;
     FAF_ATTRIB_CHILDREN=$01000;
     FAF_ATTRIB_NO_HIDDEN=$02000;
     FAF_FOLDERS_ONLY=$04000;
     FAF_NO_HIDDEN_SYS_ROMMODULES=$08000;
     FAF_GETTARGET=$10000;

     FAD_OID             =$01;
     FAD_FLAGS           =$02;
     FAD_NAME            =$04;
     FAD_TYPE            =$08;
     FAD_NUM_RECORDS     =$10;
     FAD_NUM_SORT_ORDER  =$20;
     FAD_SIZE            =$40;
     FAD_LAST_MODIFIED   =$80;
     FAD_SORT_SPECS      =$100;
     FAD_FLAG_COUNT      =9;

{$ifndef FILE_ATTRIBUTE_INROM}
{$define FILE_ATTRIBUTE_INROM        0x00000040}
{$endif}
{$ifndef FILE_ATTRIBUTE_ROMSTATICREF}
{$define FILE_ATTRIBUTE_ROMSTATICREF 0x00001000}
{$endif}
{$ifndef FILE_ATTRIBUTE_ROMMODULE}
{$define FILE_ATTRIBUTE_ROMMODULE    0x00002000}
{$endif}

//
// The following is not a standard Windows CE File Attribute.
//
{$ifndef FILE_ATTRIBUTE_HAS_CHILDREN}
{$define FILE_ATTRIBUTE_HAS_CHILDREN 0x00010000 }
{$endif}
{$ifndef FILE_ATTRIBUTE_SHORTCUT }
{$define FILE_ATTRIBUTE_SHORTCUT		0x00020000 }
{$endif}

{$undef  INTERFACE}
{$define INTERFACE   IRAPIStream}

{RAPISTREAMFLAG = (STREAM_TIMEOUT_READ);}

type
  IRAPIStream = interface(IStream)
    function SetRapiStat({THIS_ RAPISTREAMFLAG }Flag : integer; dwValue : DWORD) : HRESULT; stdcall;
    function GetRapiStat({THIS_ RAPISTREAMFLAG }Flag : integer; pdwValue : PDWORD) : HRESULT; stdcall;
  end;


// RAPI extension on Windows CE (e.g., MyFunctionFOO) called via CeRapiInvoke should be declared as:
// EXTERN_C RAPIEXT MyFunctionFOO;
{typedef  HRESULT (STDAPICALLTYPE RAPIEXT)(
		 DWORD			cbInput,			// [IN]
		 BYTE			*pInput,			// [IN]
		 DWORD			*pcbOutput,	 		// [OUT]
		 BYTE			**ppOutput,			// [OUT]
		 IRAPIStream	*pIRAPIStream		// [IN]
		 );
 }
//
// The following definitions are for the client side only,
// because they are already defined on Windows CE.
//
type

  STORE_INFORMATION=packed record
	dwStoreSize: DWORD;
	dwFreeSize: DWORD;
        end;

  LPSTORE_INFORMATION=STORE_INFORMATION;

  CEPROPID=DWORD;
  PCEPROPID=^CEPROPID;

  CEOID=DWORD;
  PCEOID=^CEOID;

  CEFILEINFO=packed record
    dwAttributes: DWORD;
    oidParent: CEOID;
    szFileName: array [0..MAX_PATH-1] of WCHAR;
    ftLastChanged: TFILETIME;
    dwLength: DWORD;
  end;

  CEDIRINFO=packed record
    dwAttributes: DWORD;
    oidParent: CEOID;
    szDirName: array [0..MAX_PATH-1] of WCHAR;
    end;

  CERECORDINFO=packed record
    oidParent: CEOID;
    end;

const
     CEDB_SORT_DESCENDING=        $00000001;
     CEDB_SORT_CASEINSENSITIVE=   $00000002;
     CEDB_SORT_UNKNOWNFIRST=      $00000004;
     CEDB_SORT_GENERICORDER=      $00000008;

type
  SORTORDERSPEC=packed record
    propid: CEPROPID;
    dwFlags: DWORD;
    end;

  PSORTORDERSPEC = ^SORTORDERSPEC;

const    
  CEDB_MAXDBASENAMELEN=  32;
  CEDB_MAXSORTORDER=     4;

  CEDB_VALIDNAME=      $0001;
  CEDB_VALIDTYPE=      $0002;
  CEDB_VALIDSORTSPEC=  $0004;
  CEDB_VALIDMODTIME=   $0008;

type  
  CEDBASEINFO=packed record
    dwFlags: DWORD;
    szDbaseName: array [0..CEDB_MAXDBASENAMELEN-1] of WCHAR;
    dwDbaseType: DWORD;
    wNumRecords: WORD;
    wNumSortOrder: WORD;
    dwSize: DWORD;
    ftLastModified: TFILETIME;
    rgSortSpecs: array [0..CEDB_MAXSORTORDER-1] of SORTORDERSPEC;
    end;

  CEDB_FIND_DATA=packed record
    OidDb: CEOID;
    DbInfo: CEDBASEINFO;
    end;

  LPCEDB_FIND_DATA = ^CEDB_FIND_DATA;
  LPLPCEDB_FIND_DATA = ^LPCEDB_FIND_DATA;

const
  OBJTYPE_INVALID=     0;
  OBJTYPE_FILE=        1;
  OBJTYPE_DIRECTORY=   2;
  OBJTYPE_DATABASE=    3;
  OBJTYPE_RECORD=      4;

type
  CEOIDINFO=packed record
    wObjType: WORD;
    wPad: WORD;
    case Integer of
         1: (infFile: CEFILEINFO);
         2: (infDirectory: CEDIRINFO);
         3: (infDatabase: CEDBASEINFO);
         4: (infRecord: CERECORDINFO);
    end;

const
  CEDB_AUTOINCREMENT=      $00000001;

  CEDB_SEEK_CEOID=         $00000001;
  CEDB_SEEK_BEGINNING=     $00000002;
  CEDB_SEEK_END=           $00000004;
  CEDB_SEEK_CURRENT=       $00000008;
  CEDB_SEEK_VALUESMALLER=     $00000010;
  CEDB_SEEK_VALUEFIRSTEQUAL=  $00000020;
  CEDB_SEEK_VALUEGREATER=     $00000040;
  CEDB_SEEK_VALUENEXTEQUAL=   $00000080;

const
  CEVT_I2=       2;
  CEVT_UI2=      18;
  CEVT_I4=       3;
  CEVT_UI4=      19;
  CEVT_FILETIME= 64;
  CEVT_LPWSTR=   31;
  CEVT_BLOB=     65;

  CEDB_PROPNOTFOUND= $0100;
  CEDB_PROPDELETE=   $0200;


type
  CEBLOB=packed record
    dwCount: DWORD;
    lpb: PBYTE;
    end;

  CEVALUNION=packed record
    case Integer of
         1: (iVal: smallint);
         2: (uiVal: WORD);
         3: (lVal: LONG);
         4: (ulVal: ULONG);
         5: (filetime: TFILETIME);
         6: (lpwstr: LPWSTR);
         7: (blob: CEBLOB);
    end;

  CEPROPVAL = packed record
    dwPropID: DWORD;
    wDataLen: word;
    wFlags: word;
    val: CEVALUNION;//po novomu
    {case Integer of
         1: (iVal: smallint);
         2: (uiVal: WORD);
         3: (lVal: LONG);
         4: (ulVal: ULONG);
         5: (filetime: TFILETIME);
         6: (lpwstr: LPWSTR);
         7: (blob: CEBLOB);}
    end;

  PCEPROPVAL = ^CEPROPVAL;

const
  CEDB_MAXDATABLOCKSIZE=  4092;
  CEDB_MAXPROPDATASIZE=   CEDB_MAXDATABLOCKSIZE*16;
  CEDB_MAXRECORDSIZE=     128*1024;

  CEDB_ALLOWREALLOC=  $00000001;

  SYSMEM_CHANGED=	0;
  SYSMEM_MUSTREBOOT= 1;
  SYSMEM_REBOOTPENDING= 2;
  SYSMEM_FAILED= 3;

type

  CEOSVERSIONINFO=packed record
    dwOSVersionInfoSize: DWORD;
    dwMajorVersion: DWORD;
    dwMinorVersion: DWORD;
    dwBuildNumber: DWORD;
    dwPlatformId: DWORD;
    szCSDVersion: array [0..128-1] of WCHAR;
    end;

  LPCEOSVERSIONINFO= ^CEOSVERSIONINFO;

const
  AC_LINE_OFFLINE=                 $00;
  AC_LINE_ONLINE=                  $01;
  AC_LINE_BACKUP_POWER=            $02;
  AC_LINE_UNKNOWN=                 $FF;

  BATTERY_FLAG_HIGH=               $01;
  BATTERY_FLAG_LOW=                $02;
  BATTERY_FLAG_CRITICAL=           $04;
  BATTERY_FLAG_CHARGING=           $08;
  BATTERY_FLAG_NO_BATTERY=         $80;
  BATTERY_FLAG_UNKNOWN=            $FF;

  BATTERY_PERCENTAGE_UNKNOWN=      $FF;

  BATTERY_LIFE_UNKNOWN=        $FFFFFFFF;

type
  SYSTEM_POWER_STATUS_EX = packed record
    ACLineStatus: BYTE;
    BatteryFlag: BYTE;
    BatteryLifePercent: BYTE;
    Reserved1: BYTE;
    BatteryLifeTime: DWORD;
    BatteryFullLifeTime: DWORD;
    Reserved2: BYTE;
    BackupBatteryFlag: BYTE;
    BackupBatteryLifePercent: BYTE;
    Reserved3: BYTE;
    BackupBatteryLifeTime: DWORD;
    BackupBatteryFullLifeTime: DWORD;
    end;

    PSYSTEM_POWER_STATUS_EX = ^SYSTEM_POWER_STATUS_EX;
    LPSYSTEM_POWER_STATUS_EX = ^SYSTEM_POWER_STATUS_EX;

  RAPIINIT=packed record
    cbSize: DWORD;
    heRapiInit: THANDLE;
    hrRapiInit: HRESULT;
    end;

  PRAPIINIT=^RAPIINIT;
    
function TypeFromPropID (propid: DWORD): WORD;

function CeRapiInitEx(RInit: PRAPIINIT): HRESULT; stdcall;
function CeRapiInit: HRESULT; stdcall;
function CeRapiUninit: HRESULT; stdcall;
function CeRapiGetError: HRESULT; stdcall;
function CeRapiFreeBuffer(buffer: pointer): HRESULT; stdcall;
function CeRapiInvoke (pDllPath: LPCWSTR; pFunctionName: LPCWSTR;
         cbInput: DWORD; Input: PBYTE; var cbOutput: DWORD; var
         pOutput: PBYTE; pIRAPIStream_:pointer{PIRAPIStream}; dwReserved: DWORD): HRESULT; stdcall;

function CeCreateDatabase (lpszName: LPWSTR; dwDbaseType: DWORD; wNumSortOrder: WORD; rgSortSpecs: PSORTORDERSPEC): CEOID; stdcall;
function CeDeleteDatabase (oidDbase: CEOID): longbool; stdcall;
function CeDeleteRecord (hDatabase: THANDLE; oidRecord: CEOID): longbool; stdcall;
function CeFindFirstDatabase (dwDbaseType: DWORD): THANDLE; stdcall;
function CeFindNextDatabase (hEnum: THANDLE): CEOID; stdcall;
function CeOidGetInfo (oid: CEOID; oidInfo: pointer {CEOIDINFO [JP]}): longbool; stdcall;
function CeOpenDatabase(poid: PCEOID; lpszName: LPWSTR;
                        SortPropID: CEPROPID; Mode: DWORD;
                        hwndNotify: HWND): THANDLE; stdcall;
function CeReadRecordProps(DBHandle: THANDLE; Mode: DWORD;
                           var PropIDCount: WORD; aCEProps: LPDWORD;
                           var Buf: PChar; var BufSize: DWORD):CEOID; stdcall;
function CeSeekDatabase (hDatabase: THANDLE; dwSeekType: DWORD; dwValue: DWORD;
         var dwIndex: DWORD): CEOID; stdcall;
function CeSetDatabaseInfo (oidDbase: CEOID; NewInfo: CEDBASEINFO): longbool; stdcall;
function CeWriteRecordProps (hDbase: THANDLE; oidRecord: CEOID; cPropID: WORD; rgPropVal: PCEPROPVAL): CEOID; stdcall;
function CeFindFirstFile (lpFileName: LPCWSTR; var FindFileData: CE_FIND_DATA): THANDLE; stdcall;
function CeFindNextFile (hFindFile: THANDLE; var FindFileData: CE_FIND_DATA): longbool; stdcall;
function CeFindClose (hFindFile: THANDLE): longbool; stdcall;
function CeGetFileAttributes (lpFileName: LPCWSTR): DWORD; stdcall;
function CeSetFileAttributes  (lpFileName: LPCWSTR; dwFileAttributes: DWORD): longbool; stdcall;
function CeCreateFile (lpFileName: LPCWSTR; dwDesiredAccess: DWORD;
         dwShareMode: DWORD; lpSecurityAttributes: PSecurityAttributes;
         dwCreationDistribution: DWORD; dwFlagsAndAttributes: DWORD; hTemplateFile: THANDLE): THANDLE; stdcall;
function CeReadFile (hFile: THANDLE; Buffer : PByte; nNumberOfBytesToRead: DWORD;
         var lpNumberOfBytesRead: DWORD; lpOverlapped_: POVERLAPPED): longbool; stdcall;
function CeWriteFile (hFile: THANDLE; Buffer : PByte; nNumberOfBytesToWrite: DWORD;
         var lpNumberOfBytesWritten: DWORD; lpOverlapped_: POVERLAPPED): longbool; stdcall;
function CeCloseHandle (hObject: THANDLE): longbool; stdcall;
function CeFindAllFiles (szPath: LPCWSTR; dwFlags: DWORD; var dwFoundCount: DWORD;
         var pFindDataArray: LPCE_FIND_DATA): longbool; stdcall;
function CeFindAllDatabases (dwDbaseType: DWORD; wFlags: WORD; var cFindData; WORD,
         pFindData: LPCEDB_FIND_DATA): longbool; stdcall;
function CeGetLastError: DWORD; stdcall;
function CeSetFilePointer (hFile: THANDLE; lDistanceToMove: LONG;
         DistanceToMoveHigh: PLONG; dwMoveMethod: DWORD): DWORD; stdcall;
function CeSetEndOfFile (hFile: THANDLE): longbool; stdcall;
function CeCreateDirectory (lpPathName: LPCWSTR; lpSecurityAttributes: PSecurityAttributes): longbool; stdcall;
function CeRemoveDirectory (lpPathName: LPCWSTR): longbool; stdcall;
function CeCreateProcess (lpApplicationName: LPCWSTR; lpCommandLine: LPCWSTR;
         lpProcessAttributes: PSecurityAttributes; lpThreadAttributes: PSecurityAttributes;
         bInheritHandles: BOOL; dwCreationFlags: DWORD; lpEnvironment: Pointer;
         lpCurrentDirectory: LPWSTR; lpStartupInfo: TSTARTUPINFO;
         var lpProcessInformation: TPROCESSINFORMATION): longbool; stdcall;
function CeMoveFile (lpExistingFileName: LPCWSTR; lpNewFileName: LPCWSTR): longbool; stdcall;
function CeCopyFile (lpExistingFileName: LPCWSTR; lpNewFileName: LPCWSTR; bFailIfExists: BOOL): longbool; stdcall;
function CeDeleteFile (lpFileName: LPCWSTR): longbool; stdcall;
function CeGetFileSize (hFile: THANDLE; lpFileSizeHigh: LPDWORD): DWORD; stdcall;
function CeRegOpenKeyEx (hKey_: HKEY; lpszSubKey: LPCWSTR; dwReserved: DWORD;
         samDesired: REGSAM; phkResult: PHKEY): LONG; stdcall;
function CeRegEnumKeyEx (hKey_: HKEY; dwIndex: DWORD; lpszName: LPWSTR; var cchName: DWORD;
         lpReserved: pointer; lpszClass: LPWSTR; lpcchClass: PDWORD;
         lpftLastWrite: PFILETIME): LONG; stdcall;
function CeRegCreateKeyEx (hKey_: HKEY; lpszSubKey: LPCWSTR; dwReserved: DWORD; lpszClass: LPWSTR;
         dwOptions: DWORD; samDesired: REGSAM; lpSecurityAttributes: PSECURITYATTRIBUTES;
         var hkResult: HKEY; lpdwDisposition: PDWORD): LONG; stdcall;
function CeRegCloseKey (hKey_: HKEY): LONG; stdcall;
function CeRegDeleteKey (hKey_: HKEY; lpszSubKey: LPCWSTR): LONG; stdcall;
function CeRegEnumValue (hKey_: HKEY; dwIndex: DWORD; lpszName: LPWSTR;
         var lpcchName: DWORD; lpReserved: Pointer; lpType: PDWORD; lpData: PBYTE;
         lpcbData: PDWORD): LONG; stdcall;
function CeRegDeleteValue (hKey_: HKEY; lpValueName: LPCWSTR): LONG; stdcall;
function CeRegQueryInfoKey (hKey_: HKEY; lpClass: LPWSTR; lpcbClass: LPDWORD;
         lpReserved: Pointer; lpcSubKeys, lpcbMaxSubKeyLen, lpcbMaxClassLen,
         lpcValues, lpcbMaxValueNameLen, lpcbMaxValueLen, lpcbSecurityDescriptor: PDWORD;
         lpftLastWriteTime: PFileTime): LONG; stdcall;
function CeRegQueryValueEx (hKey_: HKEY; lpValueName: LPCWSTR; lpReserved: Pointer;
         lpType: PDWORD; lpData: PBYTE; lpcbData: PDWORD): LONG; stdcall;
function CeRegSetValueEx (hKey_: HKEY; lpValueName: LPCWSTR; Reserved: DWORD;
         dwType: DWORD; lpData: Pointer; cbData: DWORD): LONG; stdcall;
function CeGetStoreInformation(var  lpsi: STORE_INFORMATION): longbool; stdcall;
function CeGetSystemMetrics (nIndex: integer): LONG; stdcall;
function CeGetDesktopDeviceCaps (nIndex: integer): LONG; stdcall;
procedure CeGetSystemInfo (var lpsi: TSYSTEMINFO); stdcall;
function CeSHCreateShortcut (lpszShortcut: LPWSTR; lpszTarget: LPWSTR): DWORD; stdcall;
function CeSHGetShortcutTarget (lpszShortcut: LPWSTR; lpszTarget: LPWSTR; Arg3: integer): longbool; stdcall;
function CeCheckPassword (lpszPassword: LPWSTR): longbool; stdcall;
function CeGetFileTime (hFile: THandle; lpCreationTime, lpLastAccessTime,
         lpLastWriteTime: PFileTime): longbool; stdcall;
function CeSetFileTime (hFile: THandle; lpCreationTime, lpLastAccessTime,
         lpLastWriteTime: PFileTime): longbool; stdcall;
function CeGetVersionEx (var lpcov: CEOSVERSIONINFO): longbool; stdcall;
function CeGetWindow (hWnd: HWND; uCmd: DWORD): HWND; stdcall;
function CeGetWindowLong (hWnd: HWND; nIndex: integer): LONG; stdcall;
function CeGetWindowText (hWnd: HWND; lpString: LPWSTR; nMaxCount: integer): LONG; stdcall;
function CeGetClassName (hWnd: HWND; lpClassName: LPWSTR; nMaxCount: integer): LONG; stdcall;
function CeGlobalMemoryStatus (var lpms: TMEMORYSTATUS): longbool; stdcall;
function CeGetSystemPowerStatusEx (var lpsps: SYSTEM_POWER_STATUS_EX; fUpdate: BOOL): longbool; stdcall;
function CeGetTempPath (nBufferLength: DWORD; lpBuffer: LPWSTR): DWORD; stdcall;
function CeGetSpecialFolderPath (nFolder: integer; nBufferLength: DWORD; lpBuffer: LPWSTR): DWORD; stdcall;

implementation

function TypeFromPropID (propid: DWORD): WORD;
Begin
    Result := LoWord(propid);
end;

function CeRapiInitEx; external RAPI_DLL name 'CeRapiInitEx';
function CeRapiInit; external RAPI_DLL name 'CeRapiInit';
function CeRapiUninit; external RAPI_DLL name 'CeRapiUninit';
function CeRapiGetError; external RAPI_DLL name 'CeRapiGetError';
function CeRapiFreeBuffer; external RAPI_DLL name 'CeRapiFreeBuffer';
function CeRapiInvoke; external RAPI_DLL name 'CeRapiInvoke';

function CeCreateDatabase; external RAPI_DLL name 'CeCreateDatabase';
function CeDeleteDatabase; external RAPI_DLL name 'CeDeleteDatabase';
function CeDeleteRecord; external RAPI_DLL name 'CeDeleteRecord';
function CeFindFirstDatabase; external RAPI_DLL name 'CeFindFirstDatabase';
function CeFindNextDatabase; external RAPI_DLL name 'CeFindNextDatabase';
function CeOidGetInfo; external RAPI_DLL name 'CeOidGetInfo';
function CeOpenDatabase; external RAPI_DLL name 'CeOpenDatabase';
function CeReadRecordProps; external RAPI_DLL name 'CeReadRecordProps';
function CeSeekDatabase; external RAPI_DLL name 'CeSeekDatabase';
function CeSetDatabaseInfo; external RAPI_DLL name 'CeSetDatabaseInfo';
function CeWriteRecordProps; external RAPI_DLL name 'CeWriteRecordProps';
function CeFindFirstFile; external RAPI_DLL name 'CeFindFirstFile';
function CeFindNextFile; external RAPI_DLL name 'CeFindNextFile';
function CeFindClose; external RAPI_DLL name 'CeFindClose';
function CeGetFileAttributes; external RAPI_DLL name 'CeGetFileAttributes';
function CeSetFileAttributes; external RAPI_DLL name 'CeSetFileAttributes';
function CeCreateFile; external RAPI_DLL name 'CeCreateFile';
function CeReadFile; external RAPI_DLL name 'CeReadFile';
function CeWriteFile; external RAPI_DLL name 'CeWriteFile';
function CeCloseHandle; external RAPI_DLL name 'CeCloseHandle';
function CeFindAllFiles; external RAPI_DLL name 'CeFindAllFiles';
function CeFindAllDatabases; external RAPI_DLL name 'CeFindAllDatabases';
function CeGetLastError; external RAPI_DLL name 'CeGetLastError';
function CeSetFilePointer; external RAPI_DLL name 'CeSetFilePointer';
function CeSetEndOfFile; external RAPI_DLL name 'CeSetEndOfFile';
function CeCreateDirectory; external RAPI_DLL name 'CeCreateDirectory';
function CeRemoveDirectory; external RAPI_DLL name 'CeRemoveDirectory';
function CeCreateProcess; external RAPI_DLL name 'CeCreateProcess';
function CeMoveFile; external RAPI_DLL name 'CeMoveFile';
function CeCopyFile; external RAPI_DLL name 'CeCopyFile';
function CeDeleteFile; external RAPI_DLL name 'CeDeleteFile';
function CeGetFileSize; external RAPI_DLL name 'CeGetFileSize';
function CeRegOpenKeyEx; external RAPI_DLL name 'CeRegOpenKeyEx';
function CeRegEnumKeyEx; external RAPI_DLL name 'CeRegEnumKeyEx';
function CeRegCreateKeyEx; external RAPI_DLL name 'CeRegCreateKeyEx';
function CeRegCloseKey; external RAPI_DLL name 'CeRegCloseKey';
function CeRegDeleteKey; external RAPI_DLL name 'CeRegDeleteKey';
function CeRegEnumValue; external RAPI_DLL name 'CeRegEnumValue';
function CeRegDeleteValue; external RAPI_DLL name 'CeRegDeleteValue';
function CeRegQueryInfoKey; external RAPI_DLL name 'CeRegQueryInfoKey';
function CeRegQueryValueEx; external RAPI_DLL name 'CeRegQueryValueEx';
function CeRegSetValueEx; external RAPI_DLL name 'CeRegSetValueEx';
function CeGetStoreInformation; external RAPI_DLL name 'CeGetStoreInformation';
function CeGetSystemMetrics; external RAPI_DLL name 'CeGetSystemMetrics';
function CeGetDesktopDeviceCaps; external RAPI_DLL name 'CeGetDesktopDeviceCaps';
procedure CeGetSystemInfo; external RAPI_DLL name 'CeGetSystemInfo';
function CeSHCreateShortcut; external RAPI_DLL name 'CeSHCreateShortcut';
function CeSHGetShortcutTarget; external RAPI_DLL name 'CeSHGetShortcutTarget';
function CeCheckPassword; external RAPI_DLL name 'CeCheckPassword';
function CeGetFileTime; external RAPI_DLL name 'CeGetFileTime';
function CeSetFileTime; external RAPI_DLL name 'CeSetFileTime';
function CeGetVersionEx; external RAPI_DLL name 'CeGetVersionEx';
function CeGetWindow; external RAPI_DLL name 'CeGetWindow';
function CeGetWindowLong; external RAPI_DLL name 'CeGetWindowLong';
function CeGetWindowText; external RAPI_DLL name 'CeGetWindowText';
function CeGetClassName; external RAPI_DLL name 'CeGetClassName';
function CeGlobalMemoryStatus; external RAPI_DLL name 'CeGlobalMemoryStatus';
function CeGetSystemPowerStatusEx; external RAPI_DLL name 'CeGetSystemPowerStatusEx';
function CeGetTempPath; external RAPI_DLL name 'CeGetTempPath';
function CeGetSpecialFolderPath; external RAPI_DLL name 'CeGetSpecialFolderPath';

end.
